@@ -16,12 +16,16 @@ TEXT_SUFFIXES = {
     ".asm",
     ".bat",
     ".c",
+    ".cfg",
     ".cmd",
     ".conf",
     ".cpp",
+    '.css',
+    '.csv',
     ".go",
     ".h",
     ".iml",
+    ".in",
     ".ini",
     ".js",
     ".json",
@@ -32,6 +36,7 @@ TEXT_SUFFIXES = {
     ".qmlproject",
     ".qrc",
     ".qtds",
+    '.rst',
     ".ts",
     ".txt",
     ".ui",
@@ -41,10 +46,13 @@ TEXT_SUFFIXES = {
 }
 
 TEXT_FILES = {
+    '.editorconfig',
     "license",
     "makefile",
     "qmldir",
     "qmlmodules",
+    ".gitignore",
+    ".gitattributes",
 }
 
 
