@@ -7,7 +7,11 @@ import (
 )
 
 func ShouldBind(c *fiber.Ctx, ptr interface{}) (err error) {
-	if err = c.BodyParser(ptr); err != nil {
+	if err = c.QueryParser(ptr); err != nil {
+		return err
+	}
+
+	if err = c.BodyParser(ptr); err != nil && err != fiber.ErrUnprocessableEntity {
 		return err
 	}
 
