@@ -51,10 +51,12 @@ func registerRoutes(app *iris.Application) {
 	app.OnErrorCode(http.StatusUnauthorized, api.AbortUnauthorized)
 	app.OnErrorCode(http.StatusForbidden, api.AbortPermissionDenied)
 
-	Websocket(app)
-
 	router := app.Party(conf.BasePath())
 
+	Websocket(router.Party("/ws"))
+
+	NewReverseProxyIrisExample("http://"+conf.ExternalHttpHostPort()+conf.BasePath()+"/debug", router)
+
 	// Register the request id middleware
 	router.UseRouter(requestid.New())
 
